
from setuptools import setup

setup(package_data={'pyflakes-stubs': ['__init__.pyi', '__main__.pyi', 'api.pyi', 'checker.pyi', 'messages.pyi', 'reporter.pyi', 'scripts/__init__.pyi', 'scripts/pyflakes.pyi', 'METADATA.toml', 'py.typed']})
